==> timefold-1.14.0b0.tar.gz: timefold-1.14.0b0/core/src/test/java/ai/timefold/solver/core/config/phase/custom/CustomPhaseConfigTest.java <==
package ai.timefold.solver.core.config.phase.custom;

import static org.assertj.core.api.Assertions.assertThatThrownBy;

import java.util.Collections;

import ai.timefold.solver.core.api.solver.SolverFactory;
import ai.timefold.solver.core.config.solver.SolverConfig;
import ai.timefold.solver.core.impl.phase.custom.CustomPhaseCommand;

import org.junit.jupiter.api.Test;

class CustomPhaseConfigTest {

    private static final String SOLVER_CONFIG_RESOURCE =
            "ai/timefold/solver/core/config/phase/custom/testSolverConfigWithNonexistentCustomPhase.xml";

    @Test
    void nonExistentCustomPhaseCommand() {
        assertThatThrownBy(() -> SolverFactory.createFromXmlResource(SOLVER_CONFIG_RESOURCE)
                .buildSolver())
                .isInstanceOf(IllegalArgumentException.class)
                .hasMessageContaining("customPhaseCommandClass");
    }

    @Test
    void nullCustomPhaseCommands() {
        SolverConfig solverConfig = SolverConfig.createFromXmlResource(SOLVER_CONFIG_RESOURCE);
        assertThatThrownBy(() -> ((CustomPhaseConfig) solverConfig.getPhaseConfigList().get(0))
                .withCustomPhaseCommands(new CustomPhaseCommand[] { null }))
                .isInstanceOf(IllegalArgumentException.class)
                .hasMessageContaining("Custom phase commands");
    }

    @Test
    void nullCustomPhaseCommandList() {
        SolverConfig solverConfig = SolverConfig.createFromXmlResource(SOLVER_CONFIG_RESOURCE);
        assertThatThrownBy(() -> ((CustomPhaseConfig) solverConfig.getPhaseConfigList().get(0))
                .withCustomPhaseCommandList(Collections.singletonList(null)))
                .isInstanceOf(IllegalArgumentException.class)
                .hasMessageContaining("Custom phase commands");
    }

}

==> timefold-1.20.0b0.tar.gz: timefold-1.20.0b0/core/src/test/java/ai/timefold/solver/core/config/phase/custom/CustomPhaseConfigTest.java <==
package ai.timefold.solver.core.config.phase.custom;

import static org.assertj.core.api.Assertions.assertThatThrownBy;

import java.util.Collections;

import ai.timefold.solver.core.api.solver.SolverFactory;
import ai.timefold.solver.core.api.solver.phase.PhaseCommand;
import ai.timefold.solver.core.config.solver.SolverConfig;

import org.junit.jupiter.api.Test;

class CustomPhaseConfigTest {

    private static final String SOLVER_CONFIG_RESOURCE =
            "ai/timefold/solver/core/config/phase/custom/testSolverConfigWithNonexistentCustomPhase.xml";

    @Test
    void nonExistentCustomPhaseCommand() {
        assertThatThrownBy(() -> SolverFactory.createFromXmlResource(SOLVER_CONFIG_RESOURCE)
                .buildSolver())
                .isInstanceOf(IllegalArgumentException.class)
                .hasMessageContaining("customPhaseCommandClass");
    }

    @Test
    void nullCustomPhaseCommands() {
        SolverConfig solverConfig = SolverConfig.createFromXmlResource(SOLVER_CONFIG_RESOURCE);
        assertThatThrownBy(() -> ((CustomPhaseConfig) solverConfig.getPhaseConfigList().get(0))
                .withCustomPhaseCommands(new PhaseCommand[] { null }))
                .isInstanceOf(IllegalArgumentException.class)
                .hasMessageContaining("Custom phase commands");
    }

    @Test
    void nullCustomPhaseCommandList() {
        SolverConfig solverConfig = SolverConfig.createFromXmlResource(SOLVER_CONFIG_RESOURCE);
        assertThatThrownBy(() -> ((CustomPhaseConfig) solverConfig.getPhaseConfigList().get(0))
                .withCustomPhaseCommandList(Collections.singletonList(null)))
                .isInstanceOf(IllegalArgumentException.class)
                .hasMessageContaining("Custom phase commands");
    }

}
